@@ -140,5 +140,33 @@ def nextjs_build(
                               vault_login_password, terraform_code_dir)
 
 
+@app.command()
+def nextjs_deploy(
+        fqdn: str = os.environ.get("RD_OPTION_FQDN"),
+        git_branch: str = os.environ.get("RD_OPTION_GIT_BRANCH"),
+        datacenter: str = os.environ.get('RD_OPTION_DATACENTER'),
+        organization: str = os.environ.get('RD_OPTION_ORGANIZATION'),
+        auto_apply: str = os.environ.get('RD_OPTION_AUTO_APPLY'),
+        execution_mode: str = os.environ.get('RD_OPTION_EXECUTION_MODE'),
+        deployment_environment: str = os.environ.get(
+            'RD_OPTION_DEPLOYMENT_ENVIRONMENT'),
+        deployment_action: str = os.environ.get(
+            "RD_OPTION_DEPLOYMENT_ACTION"),
+        vault_login_username: str = os.environ.get(
+            "RD_OPTION_VAULT_LOGIN_USERNAME"),
+        vault_login_password: str = os.environ.get(
+            "RD_OPTION_VAULT_LOGIN_PASSWORD"),
+        jira_issue_key: str = os.environ.get("RD_OPTION_JIRA_ISSUE_KEY"),
+        terraform_cloud_token: str = os.environ.get(
+            "RD_OPTION_TERRAFORM_CLOUD_TOKEN"),
+        terraform_code_dir: str = f"{os.path.expanduser('~')}/codebase/terraform/rootmodule/nextjs_deploy"
+
+):
+    rundeck_jobs = RundeckJobs()
+    rundeck_jobs.nextjs_deploy(fqdn, git_branch, datacenter, organization, auto_apply, execution_mode,
+                               deployment_environment, deployment_action, vault_login_username,
+                               vault_login_password, jira_issue_key, terraform_cloud_token, terraform_code_dir)
+
+
 if __name__ == "__main__":
     app()
